==> library1.4.1.tar.bz2: library/books/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //Удаление книги
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "../utils/chlang.php";

  $title = $TEXT['book-title-del'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['book_id'])>255) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['book_id'] = rep($_GET['book_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT tbl_book.book_name, tbl_book.bibl_id, tbl_biblioteka.name AS biblioteka, tbl_biblioteka.bibl_id
  FROM tbl_book
  JOIN tbl_biblioteka ON tbl_book.bibl_id=tbl_biblioteka.bibl_id
  WHERE tbl_book.book_id='".$_GET['book_id']."' ";
  $result3 = mysqli_query($dbcnx,$query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysqli_fetch_array($result3);

     //Удаляем файлы
    if(is_file($result4['photo_book'])) {unlink($result4['photo_book']);}
    if(is_file($result4['e_book'])) {unlink($result4['e_book']);}

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book2'];
  $what = $result4['book_name']." (".$TEXT['book-bibl2'].$result4['biblioteka']."), ".$TEXT['log-id'].$_GET['book_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_book` WHERE `book_id`='".$_GET['book_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
  $query_izd = "DELETE FROM `tbl_s_book_izd` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
  $query_izd = "DELETE FROM `tbl_s_book_aut` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
  $query_stat = "DELETE FROM `tbl_statistik` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl16']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl17']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}

  require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/books/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //Удаление книги
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "../utils/chlang.php";

  $title = $TEXT['book-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['book_id'])>255) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['book_id'] = rep($_GET['book_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT 
  tbl_book.book_name,
  tbl_book.bibl_id,
  tbl_book.photo_book,
  tbl_book.e_book,
  tbl_book.a_book,
  tbl_book.cd_book,
  tbl_biblioteka.name AS biblioteka,
  tbl_biblioteka.bibl_id
  FROM tbl_book
  JOIN tbl_biblioteka ON tbl_book.bibl_id=tbl_biblioteka.bibl_id
  WHERE tbl_book.book_id='".$_GET['book_id']."' ";
  $result3 = mysqli_query($dbcnx,$query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysqli_fetch_array($result3);

     //Удаляем файлы
    if(is_file($result4['photo_book'])) {unlink($result4['photo_book']);}
    if(is_file($result4['e_book'])) {unlink($result4['e_book']);}
    if(is_file($result4['a_book'])) {unlink($result4['a_book']);}
    if(is_file($result4['cd_book'])) {unlink($result4['cd_book']);}

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book2'];
  $what = $result4['book_name']." (".$TEXT['book-bibl2'].$result4['biblioteka']."), ".$TEXT['log-id'].$_GET['book_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_book` WHERE `book_id`='".$_GET['book_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
  $query_izd = "DELETE FROM `tbl_s_book_izd` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
  $query_izd = "DELETE FROM `tbl_s_book_aut` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
  $query_stat = "DELETE FROM `tbl_statistik` WHERE `book_id`='".$_GET['book_id']."'";
  if(mysqli_query($dbcnx,$query_izd))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl16']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl17']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}

  require_once "../utils/bottom_adm.php";
?>
